/**
 * @功能：获取当前登录人所对应的各个菜单下的所有的操作权限
 * @param currUserSelectMenu 当前登录用户所选中的菜单
 * @param path 项目根目录
 * @param elementId 需要将最终返回的值放到的隐藏域的id
 * 当前菜单下用户有哪些操作权限
 */
function getCurrentUserPermission(path, currUserSelectMenu, elementId) {
	$.ajax({
        type : "get",
        dataType : "json",
        async : false,
        url : path + '/system/user/loadCurrUserPermission.do',
        data : "currUserSelectMenu=" + currUserSelectMenu,
        success : function(data){
        	if (data.result == 'success') {
        		$(elementId).val(data.currUserPermission);
        	} else {
        		alijkDanger(data.message);
        	}
        },
        error : function() {
        	alijkDanger('网络异常请稍后重试!');
        } 
   });
}

/**
 * @功能:将当前用户拥有的权限操作进行格式化然后返回到前端，
 * 	这样不用每条记录都写循环代码来遍历查询出的权限
 *  例如当前登录进来的用户拥有查看和删除操作则参数格式如下{key:value}
 *  key:当前用户拥有的权限例如查看权限是：view
 *  value:查看权限所对应的链接操作:<a class="icon-pencil" style="margin-left: 20px;text-decoration:none;" href="javascript:void(0);" alt= "查看" onclick=\"javascript:check(\'' + obj.aData.userId + '\');\"></a>
 *  最后会根据用户拥有的权限将这些操作进行组合然后返回到前台(如果用户拥有的权限是*的话则可以将参数形式改为如下形式{"*":'所有的操作链接'}):
 *  { "view" :'<a class="icon-pencil" style="margin-left: 20px;text-decoration:none;" href="javascript:void(0);" alt= "查看" onclick=\"javascript:check(\'' + obj.aData.userId + '\');\"></a>'}
 *  @param object 需要展示的权限参数(格式:{"权限名称" : "对应的操作"})
 */
function formatCurrentUserPermissionOption(object) {
	
	if(!object) {
		alijkDanger('请输入权限对应的操作!');
		return false;
	} else {
		
		var permissionOpt = '';
		//通过当前登录用户选中的菜单查询出的所有的操作权限
		var permissionArr = $("#currentUserPermissionDataId").val();
		if(permissionArr.indexOf('*') != -1){
			$.each(object,function(index){
				permissionOpt += object[index];
			});
			return permissionOpt;
		}
		
		permissionArr = permissionArr.split(',');
		if (permissionArr) {
			/*if (permissionArr.length > 0) {
				for (var i = 0; i < permissionArr.length; i++) {
					if (object[permissionArr[i]]) {
						permissionOpt += object[permissionArr[i]];
					} 
				}
				return permissionOpt;
			}*/
			
			for ( var per in object) {
				if (permissionArr.length > 0) {
					for (var i = 0; i < permissionArr.length; i++) {
						/*if (object[permissionArr[i]]) {
							permissionOpt += object[permissionArr[i]];
						} */
						if (per == permissionArr[i]) {
							permissionOpt += object[per];
						} 
					}
				}
			}
			return permissionOpt;
		}
	}
	
	
}

/**
 * 	判断当前登陆用户是否具有operate权限
 */
function checkCurrentUserPermissionOption(operate) {

	var permissionOpt = '';
	
	//通过当前登录用户选中的菜单查询出的所有的操作权限
	var permissionArr = $("#currentUserPermissionDataId").val();
	
	if(permissionArr.indexOf('*') != -1){
		return true;
	}
	if(permissionArr.indexOf(operate) != -1){
		return true;
	}
	
	return false;
	
}